# import components from csv cut list, per request by Vigy
#
# Notes:
# This is bare-bones, assuming the column layout from a sample file from Vigy.
# It does not process the header line, so it will break if columns are rearranged.
# This ignores the following fields for the stated reasons:
# - material: there isn't enough info to create a material in SketchUp
# - quantity: all the examples were 1.  Could be changed.
# - if the csv was generated with a pre-OS X app, it may have line endings that
#  won't be processed correctly here (OS 9 used carriage returns, OS X uses line feeds).
# The simplest attack is to convert the file, e.g. using tr '\r' '\n', rather than make
# the code here more complicated.

require "sketchup"

module SLBPlugins
  module Climport
    def self.import_cut_list
      mod=Sketchup.active_model
      ents = mod.entities
      layers=mod.layers
      base_y=0.0
      gap=1.0
      csvpath = UI.openpanel("CSV file to open", ".", "*.csv")

      File.open(csvpath) do |file|
          header = file.gets
          while line=file.gets
            line.chomp!
            id,material,y,x,z,quantity,layer=line.split(",")
            fx=x.to_f
            fy=y.to_f
            fz=z.to_f
            gp=ents.add_group
            gents = gp.entities
            base=gents.add_face([0.0,base_y,0.0],[fx,base_y,0.0],[fx,base_y+fy,0.0],[0.0,base_y+fy,0.0])
            base.pushpull(-fz, false)
            ci=gp.to_component
            ci.definition.name=id
            if(!layers[layer])
              layers.add layer
            end
            ci.layer = layer
            base_y = base_y + fy + gap
          end
        end
    end

    if !file_loaded?("importcutlist.rb")
      UI.menu( "Plugins" ).add_item( "Import Cut List" ) { import_cut_list }
      file_loaded("importcutlist.rb")
    end
    
  end
end
